import os
import FreeCADGui as Gui
from pivy import coin

from .. import settings

class BaseViewProvider:
    def __init__(self, parent, viewprovider):
        self.parent = parent
        self.viewprovider = viewprovider

        self.icon = os.path.join(settings.ICONPATH, self.parent.__class__.ICON)

        viewprovider.Proxy = self
        
        self.Type = ''

        if hasattr(parent.__class__, 'TYPE'):
            self.Type = parent.__class__.TYPE

        self.setup_extensions()

    def setup_extensions(self):
        if hasattr(self.parent.__class__, 'VIEWPROVIDER_EXTENSIONS'):
            for ext in self.parent.__getstate__.VIEWPROVIDER_EXTENSIONS:
                self.feature.addExtension(ext)

    def attach(self, vobj):
        self.standard = coin.SoGroup()
        vobj.addDisplayMode(self.standard, "Standard")

    def doubleClicked(self, vobj):
        Gui.activateWorkbench("KiConnect")
        Gui.Selection.clearSelection()

    def getIcon(self):
        return self.icon

    def getDisplayModes(self,obj):
        '''Return a list of display modes.'''
        return [ 'Standard' ]

    def getDefaultDisplayMode(self):
        '''Return the name of the default display mode. It must be defined in getDisplayModes.'''
        return 'Standard'

    def __getstate__(self):
        return {
            'icon': self.icon
        }

    def __setstate__(self, props):
        for prop in props:
            setattr(self, prop, props[prop])
